@@ -40,7 +40,7 @@ static void		restore_window_child	(BonoboMDI *, GHashTable *,
 						 GHashTable *, GHashTable *,
 						 GHashTable *, GHashTable *,
 						 glong, glong, gboolean *,
-						 gchar *);
+						 gint, gint, gint, gint);
 static void		restore_window		(BonoboMDI *, const gchar *,
 						 GPtrArray *, GHashTable *,
 						 GHashTable *, GHashTable *,
@@ -118,7 +118,7 @@ restore_window_child (BonoboMDI *mdi, GHashTable *child_hash,
 		      GHashTable *child_windows, GHashTable *child_views,
 		      GHashTable *view_hash, GHashTable *window_hash,
 		      glong window, glong child, gboolean *init,
-		      gchar *role)
+		      gint x, gint y, gint width, gint height)
 {
 	GPtrArray *windows, *views;
 	BonoboMDIChild *mdi_child;
@@ -140,8 +140,16 @@ restore_window_child (BonoboMDI *mdi, GHashTable *child_hash,
 		if (*init)
 			bonobo_mdi_add_view (mdi, mdi_child);
 		else {
-			bonobo_mdi_add_toplevel_view (mdi, mdi_child, role);
-			
+			bonobo_mdi_add_toplevel_view (mdi, mdi_child);
+#if 0
+			/* FIXME: this needs to be done with window roles */
+			gtk_widget_set_usize
+				(GTK_WIDGET (bonobo_mdi_get_active_window (mdi)),
+				 width, height);
+
+			gtk_widget_set_uposition
+				(GTK_WIDGET (bonobo_mdi_get_active_window (mdi)), x, y);
+#endif
 			*init = TRUE;
 
 			g_hash_table_insert (window_hash,
@@ -162,15 +170,28 @@ restore_window (BonoboMDI *mdi, const gchar *section, GPtrArray *child_list,
 		GHashTable *window_hash, glong window)
 {
 	gboolean init = FALSE;
-	gchar key [BUFSIZ], *role;
+	gchar key [BUFSIZ], *string;
+	gint ret, x, y, w, h;
 	guint j;
 
 	g_snprintf (key, sizeof(key), "%s/mdi_window_%lx", section, window);
-	role = gnome_config_get_string (key);
+	string = gnome_config_get_string (key);
+	if (!string) return;
+
+	ret = sscanf (string, "%d/%d/%d/%d", &x, &y, &w, &h);
+	g_free (string);
+	if (ret != 4) return;
 
 	if(child_list->len == 0) {
-		bonobo_mdi_open_toplevel (mdi, role);
+		bonobo_mdi_open_toplevel (mdi);
 	
+#if 0
+		/* FIXME: this needs to be done with window roles */
+		gtk_widget_set_usize (GTK_WIDGET (bonobo_mdi_get_active_window (mdi)), w, h);
+
+		gtk_widget_set_uposition (GTK_WIDGET (bonobo_mdi_get_active_window (mdi)),
+					  x, y);
+#endif
 		g_hash_table_insert (window_hash, (gpointer) window,
 				     bonobo_mdi_get_active_window (mdi));
  	}
@@ -180,14 +201,13 @@ restore_window (BonoboMDI *mdi, const gchar *section, GPtrArray *child_list,
 					      child_views, view_hash,
 					      window_hash, window,
 					      (glong) child_list->pdata [j],
-					      &init, role);
-
-#if 0
+					      &init, x, y, w, h);
 
 	g_snprintf (key, sizeof(key), "%s/mdi_window_layout_%lx", section, window);
 	string = gnome_config_get_string (key);
 	if (!string) return;
 
+#if 0
 	{
 		BonoboWindow *app = bonobo_mdi_get_active_window (mdi);
 		BonoboDockLayout *layout;
@@ -203,8 +223,6 @@ restore_window (BonoboMDI *mdi, const gchar *section, GPtrArray *child_list,
 		g_object_unref (G_OBJECT(layout));
 	}
 #endif
-	if (role != NULL)
-		g_free (role);
 }
 
 static void
@@ -240,7 +258,6 @@ gboolean
 bonobo_mdi_restore_state (BonoboMDI *mdi, const gchar *section,
 			 BonoboMDIChildCreator create_child_func)
 {
-	gboolean retval;
 	gchar key [BUFSIZ], *string;
 	GPtrArray *window_list, *child_list;
 	GHashTable *child_hash, *child_windows;
@@ -249,14 +266,10 @@ bonobo_mdi_restore_state (BonoboMDI *mdi, const gchar *section,
 	guint i;
 	gint mode;
 
-	retval = FALSE;
-
-	bonobo_mdi_set_restoring_state (mdi, TRUE);
-
 	g_snprintf (key, sizeof(key), "%s/mdi_mode=-1", section);
 	mode = gnome_config_get_int (key);
 	if (gnome_config_get_int (key) == -1)
-		goto out;
+		return FALSE;
 #if 0
 	bonobo_mdi_set_mode (mdi, mode);
 #endif
@@ -384,12 +397,7 @@ bonobo_mdi_restore_state (BonoboMDI *mdi, const gchar *section,
 	g_hash_table_destroy (view_hash);
 	g_hash_table_destroy (window_hash);
 
-	retval = TRUE;
-
- out:
-	bonobo_mdi_set_restoring_state (mdi, FALSE);
-
-	return retval;
+	return TRUE;
 }
 
 static gpointer
@@ -414,6 +422,7 @@ bonobo_mdi_save_state (BonoboMDI *mdi, const gchar *section)
 {
 	gchar key [BUFSIZ], value [BUFSIZ];
 	GList *child, *window;
+	gint x, y, w, h;
 
 	gnome_config_clean_section (section);
 
@@ -488,7 +497,6 @@ bonobo_mdi_save_state (BonoboMDI *mdi, const gchar *section)
 	while (window) {
 		BonoboWindow *app;
 		GtkWidget *view;
-		const gchar *role;
 #ifdef SNM
 		gchar *string;
 		BonoboDockLayout *layout;
@@ -496,15 +504,17 @@ bonobo_mdi_save_state (BonoboMDI *mdi, const gchar *section)
 
 		app = BONOBO_WINDOW (window->data);
 
-		role = gtk_window_get_role (GTK_WINDOW (app));
+		gdk_window_get_geometry (GTK_WIDGET (app)->window,
+					 &x, &y, &w, &h, NULL);
+
+		gdk_window_get_origin (GTK_WIDGET (app)->window, &x, &y);
+
+		g_snprintf (key, sizeof(key), "%s/mdi_window_%lx",
+			    section, (long) app);
+		g_snprintf (value, sizeof(value), "%d/%d/%d/%d", x, y, w, h);
+
+		gnome_config_set_string (key, value);
 
-		if (role != NULL)
-		{
-			g_snprintf (key, sizeof(key), "%s/mdi_window_%lx",
-				    section, (long) app);
-			gnome_config_set_string (key, role);
-		}
-		
 		view = bonobo_mdi_get_view_from_window (mdi, app);
 
 		g_snprintf (key, sizeof(key), "%s/mdi_window_view_%lx",
